pub struct UntrustedMembershipsResponse {
emergency_access_memberships: Vec<V1EmergencyAccessMembership>,
organization_memberships: Vec<V1OrganizationMembership>,
}Expand description
Response model for untrusted memberships, containing both organization and emergency access memberships.
Fields
emergency_access_memberships: Vec<V1EmergencyAccessMembership>organization_memberships: Vec<V1OrganizationMembership>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for UntrustedMembershipsResponse
impl<'de> Deserialize<'de> for UntrustedMembershipsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<UntrustedMembershipsResponse> for JsValue
impl From<UntrustedMembershipsResponse> for JsValue
Sourcefn from(value: UntrustedMembershipsResponse) -> Self
fn from(value: UntrustedMembershipsResponse) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
impl FromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
Sourceimpl OptionFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
Sourceimpl RefFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<UntrustedMembershipsResponse>
type Anchor = SelfOwner<UntrustedMembershipsResponse>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Tsify for UntrustedMembershipsResponse
impl Tsify for UntrustedMembershipsResponse
const DECL: &'static str = "/**\n * Response model for untrusted memberships, containing both organization and emergency access\n * memberships.\n */\nexport interface UntrustedMembershipsResponse {\n emergency_access_memberships: V1EmergencyAccessMembership[];\n organization_memberships: V1OrganizationMembership[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for UntrustedMembershipsResponsewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for UntrustedMembershipsResponse
impl VectorIntoWasmAbi for UntrustedMembershipsResponse
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi